from torchcam import methods, utils

try:
    from .version import __version__  # noqa: F401
except ImportError:
    pass
